==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/pt_PT.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documentos",
"Can't create document" => "Não é possível criar o documento",
"You don't have permission to rename this document" => "Não tem permissão para renomear este documento",
"Directory saved successfully." => "Diretoria guardada com sucesso.",
"An error occurred while changing directory." => "Ocorreu um erro ao mudar de diretoria.",
"Saved" => "Guardado",
"Format filter server is down or misconfigured" => "O servidor do filtro de formatação está em baixo ou mal configurado",
"Conversion failed. Check log for details." => "A conversão falhou. Verifique o registo para detalhes.",
"document-styles" => "estilos-documento",
"document-content" => "conteúdo-documento",
"bold" => "negrito",
"italic" => "itálico",
"solid" => "solido",
"pt" => "pt",
"Saving..." => "A guardar...",
"Failed to load documents." => "Não foi possível carregar os documentos.",
"No documents were found. Upload or create a document to get started!" => "Não foram encontrados quaisquer documentos. Envie ou crie um documento para começar!",
"No connection to server. Trying to reconnect." => "Sem conexão ao servidor. A tentar reconetar.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Ao sair desta página no modo Editor poderá deixar dados não guardados. Em vez disso, é recomendado a utilização do botão 'Fechar'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Não foi possível carregar este documento. Por favor, verifique se este pode ser aberto com um editor odt externo. Isto poderá significar que este foi apagado recentemente ou a partilha foi cancelada.",
"Save" => "Guardar",
"Loading documents..." => "A carregar os documentos ...",
"'.' is an invalid file name." => "'.' não é um nome de ficheiro válido.",
"File name cannot be empty." => "O nome do ficheiro não pode estar em branco.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Nome inválido, os carateres '\\', '/', '<', '>', ':', '\"', '|', '?' e '*' não são permitidos.",
"Align Left" => "Alinhar à Esquerda",
"Alignment" => "Alinhamento",
"Align Right" => "Alinhar à Direita",
"Annotate" => "Anotar",
"Background" => "Fundo",
"Bold" => "Negrito",
"Bottom" => "Base",
"Cancel" => "Cancelar",
"Center" => "Centro",
"Clone" => "Clonar",
"Clone this Style" => "Clonar este Estilo",
"Close" => "Fechar",
"Color" => "Cor",
"Create" => "Criar",
"Decrease Indent" => "Diminuir Indentação",
"Default Style" => "Estilo Predefinido",
"Delete" => "Apagar",
"Family" => "Familia",
"Font" => "Tipo de letra",
"Font Effects" => "Efeitos de Letra",
"Format" => "Formato",
"Increase Indent" => "Aumentar Indentação",
"Insert Image" => "Inserir Imagem",
"Invite Members" => "Convidar Membros",
"Italic" => "Itálico",
"Justified" => "Justificado",
"Justify" => "Justificar",
"Left" => "Esquerda",
"Loading" => "A carregar ...",
"Members" => "Membros",
"New Name:" => "Novo Nome:",
"OK" => "CONFIRMAR",
"Open" => "Abrir",
"Options" => "Opções",
"Paragraph..." => "Parágrafo ...",
"Paragraph Styles" => "Estilos de Parágrafo",
"Redo" => "Refazer",
"Right" => "Direita",
"Size" => "Tamanho",
"Spacing" => "Espaçamento",
"Strikethrough" => "Rasurado",
"Style" => "Estilo",
"Text" => "Texto",
"Top" => "Topo",
"Underline" => "Sublinhado",
"Undo" => "Anular",
"Unknown Author" => "Autor Desconhecido",
"Edit" => "Editar",
"Share" => "Compartilhar",
"guest" => "convidado",
"MS Word support (requires openOffice/libreOffice)" => "Suporte para MS Word (requer openOffice/libreOffice)",
"Local" => "Local",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice está instalado neste servidor. O caminho para o binário é disponibilizado via preview_libreoffice_path no config.php",
"External" => "Externo",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice está instalado num servidor externo, a executar um servidor de filtro de formato",
"Disabled" => "Desactivada",
"No MS Word support" => "Suporte MS Word indisponível",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "URL do Servidor",
"Apply and test" => "Aplicar e Testar",
"New document" => "Novo documento",
"Upload (max. %s)" => "Enviar (máx. %s)",
"Upload" => "Enviar",
"Save new documents to" => "Guarde os novos documentos em",
"Wrong password. Please retry." => "Senha errada. Por favor, tente de novo.",
"Password" => "Senha",
"Guest %s" => "Convidado %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Esta hiperligação expirou ou nunca existiu. Para mais detalhes, por favor, contacte a pessoa que a partilhou consigo.",
"Advanced feature-set" => "Opções Avançadas",
"(Unstable)" => "(Instável)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/pt_PT.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documentos",
"Can't create document" => "Não é possível criar o documento",
"You don't have permission to rename this document" => "Não tem permissão para renomear este documento",
"Directory saved successfully." => "Diretoria guardada com sucesso.",
"An error occurred while changing directory." => "Ocorreu um erro ao mudar de diretoria.",
"Saved" => "Guardado",
"Format filter server is down or misconfigured" => "O servidor do filtro de formatação está em baixo ou mal configurado",
"Conversion failed. Check log for details." => "A conversão falhou. Verifique o registo para detalhes.",
"Saving..." => "A guardar...",
"Failed to load documents." => "Não foi possível carregar os documentos.",
"No documents were found. Upload or create a document to get started!" => "Não foram encontrados quaisquer documentos. Envie ou crie um documento para começar!",
"No connection to server. Trying to reconnect." => "Sem conexão ao servidor. A tentar reconetar.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Ao sair desta página no modo Editor poderá deixar dados não guardados. Em vez disso, é recomendado a utilização do botão 'Fechar'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Não foi possível carregar este documento. Por favor, verifique se este pode ser aberto com um editor odt externo. Isto poderá significar que este foi apagado recentemente ou a partilha foi cancelada.",
"Save" => "Guardar",
"Loading documents..." => "A carregar os documentos ...",
"'.' is an invalid file name." => "'.' não é um nome de ficheiro válido.",
"File name cannot be empty." => "O nome do ficheiro não pode estar em branco.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Nome inválido, os carateres '\\', '/', '<', '>', ':', '\"', '|', '?' e '*' não são permitidos.",
"Align Left" => "Alinhar à Esquerda",
"Alignment" => "Alinhamento",
"Align Right" => "Alinhar à Direita",
"Annotate" => "Anotar",
"Background" => "Fundo",
"Bold" => "Negrito",
"Bottom" => "Base",
"Cancel" => "Cancelar",
"Center" => "Centro",
"Clone" => "Clonar",
"Clone this Style" => "Clonar este Estilo",
"Close" => "Fechar",
"Color" => "Cor",
"Create" => "Criar",
"Decrease Indent" => "Diminuir Indentação",
"Default Style" => "Estilo Predefinido",
"Delete" => "Apagar",
"Family" => "Familia",
"Font" => "Tipo de letra",
"Font Effects" => "Efeitos de Letra",
"Format" => "Formato",
"Increase Indent" => "Aumentar Indentação",
"Insert Image" => "Inserir Imagem",
"Invite Members" => "Convidar Membros",
"Italic" => "Itálico",
"Justified" => "Justificado",
"Justify" => "Justificar",
"Left" => "Esquerda",
"Loading" => "A carregar ...",
"Members" => "Membros",
"New Name:" => "Novo Nome:",
"OK" => "CONFIRMAR",
"Open" => "Abrir",
"Options" => "Opções",
"Paragraph..." => "Parágrafo ...",
"Paragraph Styles" => "Estilos de Parágrafo",
"Redo" => "Refazer",
"Right" => "Direita",
"Size" => "Tamanho",
"Spacing" => "Espaçamento",
"Strikethrough" => "Rasurado",
"Style" => "Estilo",
"Text" => "Texto",
"Top" => "Topo",
"Underline" => "Sublinhado",
"Undo" => "Anular",
"Unknown Author" => "Autor Desconhecido",
"Shared" => "Partilhado",
"Error" => "Erro",
"Error while sharing" => "Erro ao partilhar",
"Error while unsharing" => "Erro ao remover a partilha",
"Error while changing permissions" => "Erro ao mudar permissões",
"Shared with you and the group {group} by {owner}" => "Partilhado consigo e com o grupo {group} por {owner}",
"Shared with you by {owner}" => "Partilhado consigo por {owner}",
"Share with users or groups …" => "Partilhar com utilizadores ou grupos...",
"Share with users, groups or remote users …" => "Partilhar com utilizadores, grupos ou utilizadores remotos...",
"Share" => "Compartilhar",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Compartilhe com as pessoas nas outras ownClouds utilizando a sintaxe username@example.com/owncloud",
"Share link" => "Compartilhar hiperligação",
"The public link will expire no later than {days} days after it is created" => "O link público expira, o mais tardar {days} dias após sua criação",
"Link" => "Hiperligação",
"Password protect" => "Proteger com Palavra-passe",
"Password" => "Senha",
"Choose a password for the public link" => "Escolha a senha para a hiperligação pública",
"Allow editing" => "Permitir edição",
"Email link to person" => "Enviar a hiperligação para a pessoa",
"Send" => "Enviar",
"Set expiration date" => "Definir a data de expiração",
"Expiration" => "Expira em",
"Expiration date" => "Data de expiração",
"An error occured. Please try again" => "Ocorreu um erro. Por favor, tente de novo",
"Adding user..." => "A adicionar o utilizador ...",
"group" => "grupo",
"remote" => "remoto",
"Resharing is not allowed" => "Não é permitido partilhar de novo",
"Shared in {item} with {user}" => "Partilhado em {item} com {user}",
"Unshare" => "Cancelar partilha",
"notify by email" => "Notificar por correio eletrónico",
"can share" => "pode partilhar",
"can edit" => "pode editar",
"access control" => "controlo de acesso",
"create" => "criar",
"change" => "alterar",
"delete" => "eliminar",
"Password protected" => "Protegido com Palavra-passe",
"Error unsetting expiration date" => "Erro ao retirar a data de expiração",
"Error setting expiration date" => "Erro ao aplicar a data de expiração",
"Sending ..." => "A Enviar...",
"Email sent" => "Mensagem enviada",
"Warning" => "Aviso",
"Edit" => "Editar",
"guest" => "convidado",
"MS Word support (requires openOffice/libreOffice)" => "Suporte para MS Word (requer openOffice/libreOffice)",
"Local" => "Local",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice está instalado neste servidor. O caminho para o binário é disponibilizado via preview_libreoffice_path no config.php",
"External" => "Externo",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice está instalado num servidor externo, a executar um servidor de filtro de formato",
"Disabled" => "Desactivada",
"No MS Word support" => "Suporte MS Word indisponível",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "URL do Servidor",
"Apply and test" => "Aplicar e Testar",
"New document" => "Novo documento",
"Upload (max. %s)" => "Enviar (máx. %s)",
"Upload" => "Enviar",
"Save new documents to" => "Guarde os novos documentos em",
"Wrong password. Please retry." => "Senha errada. Por favor, tente de novo.",
"Guest %s" => "Convidado %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Esta hiperligação expirou ou nunca existiu. Para mais detalhes, por favor, contacte a pessoa que a partilhou consigo.",
"Advanced feature-set" => "Opções Avançadas",
"(Unstable)" => "(Instável)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
